@@ -3,8 +3,7 @@ import django.dispatch
 
 __all__ = [
     "twilio_2fa_verification_sent", "twilio_2fa_verification_success", "twilio_2fa_verification_status_changed",
-    "twilio_2fa_verification_failed", "twilio_2fa_verification_retries_exceeded", "twilio_2fa_verification_start",
-    "twilio_2fa_rate_limited",
+    "twilio_2fa_verification_failed", "twilio_2fa_set_user_data", "twilio_2fa_twilio_error",
 ]
 
 
@@ -16,8 +15,6 @@ twilio_2fa_verification_status_changed = django.dispatch.Signal()
 
 twilio_2fa_verification_failed = django.dispatch.Signal()
 
-twilio_2fa_verification_retries_exceeded = django.dispatch.Signal()
+twilio_2fa_set_user_data = django.dispatch.Signal()
 
-twilio_2fa_verification_start = django.dispatch.Signal()
-
-twilio_2fa_rate_limited = django.dispatch.Signal()
+twilio_2fa_twilio_error = django.dispatch.Signal()
