@@ -128,16 +128,14 @@ def verify_phone_number(phone_number, country_code, do_lookup=False):
         default=["mobile"]
     )
 
-    allowed_methods = get_setting(
-        "ALLOWED_METHODS",
-        default=["sms", "call"]
-    )
-
     res = {}
 
     if do_lookup and not do_lookup_setting:
         do_lookup = False
 
+    if country_code not in allowed_country_codes or country_code in disallowed_country_codes:
+        raise ValidationError(f"We do not allow phone numbers originating from {country_code}.")
+
     phone_number = parse_phone_number(phone_number, country_code)
 
     if not phonenumbers.is_valid_number(phone_number):
@@ -158,10 +156,6 @@ def verify_phone_number(phone_number, country_code, do_lookup=False):
         if country_code not in allowed_country_codes or country_code in disallowed_country_codes:
             raise ValidationError(f"We do not allow phone numbers originating from {country_code}.")
 
-        if carrier_type is None:
-            if allowed_methods and "call" not in allowed_methods:
-                raise ValidationError(f"Invalid phone number.")
-
         if carrier_type not in allowed_carrier_types:
             raise ValidationError(f"{carrier_type.title()} phone numbers are not allowed. "
                                   f"Must be a {' or '.join(allowed_carrier_types)} phone number.")
